@@ -5,12 +5,7 @@ use crate::{
     cmd_log::CmdLogEntry, items::TargetData, menu::Menu, prompt::PromptData, state::State,
     term::Term, Res,
 };
-use std::{
-    ffi::{OsStr, OsString},
-    fmt::Display,
-    process::Command,
-    rc::Rc,
-};
+use std::{fmt::Display, rc::Rc};
 
 pub(crate) mod checkout;
 pub(crate) mod commit;
@@ -185,14 +180,6 @@ impl Display for Menu {
     }
 }
 
-pub(crate) fn cmd(input: Vec<u8>, command: fn() -> Command) -> Action {
-    Rc::new(move |state, term| state.run_cmd(term, &input, command()))
-}
-
-pub(crate) fn cmd_arg(command: fn(&OsStr) -> Command, arg: OsString) -> Action {
-    Rc::new(move |state, term| state.run_cmd(term, &[], command(&arg)))
-}
-
 pub(crate) fn create_y_n_prompt(mut action: Action, prompt: &'static str) -> Action {
     let update_fn = Rc::new(move |state: &mut State, term: &mut Term| {
         if state.prompt.state.status().is_pending() {
@@ -225,48 +212,85 @@ pub(crate) fn create_y_n_prompt(mut action: Action, prompt: &'static str) -> Act
 
 pub(crate) fn create_prompt(
     prompt: &'static str,
-    callback: fn(&mut State, &mut Term, &[OsString], &str) -> Res<()>,
+    callback: fn(&mut State, &mut Term, &str) -> Res<()>,
+    hide_menu: bool,
 ) -> Action {
-    create_prompt_with_default(prompt, callback, |_| None)
+    create_prompt_with_default(prompt, callback, |_| None, hide_menu)
 }
 
 pub(crate) fn create_prompt_with_default(
     prompt: &'static str,
-    callback: fn(&mut State, &mut Term, &[OsString], &str) -> Res<()>,
+    callback: fn(&mut State, &mut Term, &str) -> Res<()>,
     default_fn: fn(&State) -> Option<String>,
+    hide_menu: bool,
 ) -> Action {
     Rc::new(move |state: &mut State, _term: &mut Term| {
-        let prompt_text = if let Some(default) = default_fn(state) {
-            format!("{} (default {}):", prompt, default).into()
-        } else {
-            format!("{}:", prompt).into()
-        };
-
-        let args = state.pending_menu.as_ref().unwrap().args();
-
-        state.prompt.set(PromptData {
-            prompt_text,
-            update_fn: Rc::new(move |state, term| {
-                if state.prompt.state.status().is_done() {
-                    let input = state.prompt.state.value().to_string();
-                    state.prompt.reset(term)?;
-
-                    let default_value = default_fn(state);
-                    let value = match (input.as_str(), &default_value) {
-                        ("", None) => "",
-                        ("", Some(selected)) => selected,
-                        (value, _) => value,
-                    };
-
-                    callback(state, term, &args, value)?;
-                }
-                Ok(())
-            }),
-        });
+        set_prompt(
+            state,
+            prompt,
+            invoke_default,
+            Box::new(default_fn),
+            callback,
+            hide_menu,
+        );
         Ok(())
     })
 }
 
+fn invoke_default(
+    state: &mut State,
+    term: &mut Term,
+    value: &str,
+    context: &fn(&mut State, &mut Term, &str) -> Res<()>,
+) -> Res<()> {
+    context(state, term, value)
+}
+
+type DefaultFn = Box<dyn Fn(&State) -> Option<String>>;
+
+pub(crate) fn set_prompt<T: 'static>(
+    state: &mut State,
+    prompt: &'static str,
+    callback: fn(&mut State, &mut Term, &str, &T) -> Res<()>,
+    default_fn: DefaultFn,
+    context: T,
+    hide_menu: bool,
+) {
+    let prompt_text = if let Some(default) = default_fn(state) {
+        format!("{} (default {}):", prompt, default).into()
+    } else {
+        format!("{}:", prompt).into()
+    };
+
+    if hide_menu {
+        state.hide_menu();
+    }
+
+    state.prompt.set(PromptData {
+        prompt_text,
+        update_fn: Rc::new(move |state, term| {
+            if state.prompt.state.status().is_done() {
+                let input = state.prompt.state.value().to_string();
+                state.prompt.reset(term)?;
+
+                let default_value = default_fn(state);
+                let value = match (input.as_str(), &default_value) {
+                    ("", None) => "",
+                    ("", Some(selected)) => selected,
+                    (value, _) => value,
+                };
+
+                callback(state, term, value, &context)?;
+
+                if hide_menu {
+                    state.unhide_menu();
+                }
+            }
+            Ok(())
+        }),
+    });
+}
+
 pub(crate) fn selected_rev(state: &State) -> Option<String> {
     match &state.screen().get_selected_item().target_data {
         Some(TargetData::Branch(branch)) => Some(branch.to_owned()),
