@@ -7,19 +7,21 @@ use std::{
     rc::Rc,
 };
 
-pub(crate) const ARGS: &[Arg] = &[
-    Arg::new("--keep-empty", "Keep empty commits", false),
-    Arg::new("--preserve-merges", "Preserve merges", false),
-    Arg::new(
-        "--committer-date-is-author-date",
-        "Lie about committer date",
-        false,
-    ),
-    Arg::new("--autosquash", "Autosquash", false),
-    Arg::new("--autostash", "Autostash", true),
-    Arg::new("--interactive", "Interactive", false),
-    Arg::new("--no-verify", "Disable hooks", false),
-];
+pub(crate) fn init_args() -> Vec<Arg> {
+    vec![
+        Arg::new_flag("--keep-empty", "Keep empty commits", false),
+        Arg::new_flag("--preserve-merges", "Preserve merges", false),
+        Arg::new_flag(
+            "--committer-date-is-author-date",
+            "Lie about committer date",
+            false,
+        ),
+        Arg::new_flag("--autosquash", "Autosquash", false),
+        Arg::new_flag("--autostash", "Autostash", true),
+        Arg::new_flag("--interactive", "Interactive", false),
+        Arg::new_flag("--no-verify", "Disable hooks", false),
+    ]
+}
 
 #[derive(Display)]
 #[display(fmt = "Rebase continue")]
@@ -30,6 +32,7 @@ impl OpTrait for RebaseContinue {
             let mut cmd = Command::new("git");
             cmd.args(["rebase", "--continue"]);
 
+            state.close_menu();
             state.run_cmd_interactive(term, cmd)?;
             Ok(())
         }))
@@ -45,6 +48,7 @@ impl OpTrait for RebaseAbort {
             let mut cmd = Command::new("git");
             cmd.args(["rebase", "--abort"]);
 
+            state.close_menu();
             state.run_cmd(term, &[], cmd)?;
             Ok(())
         }))
@@ -60,16 +64,18 @@ impl OpTrait for RebaseElsewhere {
             "Rebase onto",
             rebase_elsewhere,
             selected_rev,
+            true,
         ))
     }
 }
 
-fn rebase_elsewhere(state: &mut State, term: &mut Term, args: &[OsString], rev: &str) -> Res<()> {
+fn rebase_elsewhere(state: &mut State, term: &mut Term, rev: &str) -> Res<()> {
     let mut cmd = Command::new("git");
     cmd.arg("rebase");
-    cmd.args(args);
+    cmd.args(state.pending_menu.as_ref().unwrap().args());
     cmd.arg(rev);
 
+    state.close_menu();
     state.run_cmd_interactive(term, cmd)?;
     Ok(())
 }
@@ -84,6 +90,7 @@ impl OpTrait for RebaseInteractive {
                 let rev = OsString::from(r);
                 Rc::new(move |state: &mut State, term: &mut Term| {
                     let args = state.pending_menu.as_ref().unwrap().args();
+                    state.close_menu();
                     state.run_cmd_interactive(term, rebase_interactive_cmd(&args, &rev))
                 })
             }
@@ -121,6 +128,7 @@ impl OpTrait for RebaseAutosquash {
                 let rev = OsString::from(r);
                 Rc::new(move |state: &mut State, term: &mut Term| {
                     let args = state.pending_menu.as_ref().unwrap().args();
+                    state.close_menu();
                     state.run_cmd_interactive(term, rebase_autosquash_cmd(&args, &rev))
                 })
             }
