@@ -20,3 +20,13 @@ fn open_push_menu_after_dash_input() {
     commit(ctx.dir.path(), "new-file", "");
     snapshot!(ctx, "-P");
 }
+
+#[test]
+fn push_elsewhere_prompt() {
+    snapshot!(TestContext::setup_clone(), "Pe");
+}
+
+#[test]
+fn push_elsewhere() {
+    snapshot!(TestContext::setup_clone(), "Peorigin<enter>");
+}
